@@ -42,5 +42,8 @@ func main() {
 	if _, err := captcha.NewImage("", d, *flagImgW, *flagImgH).WriteTo(f); err != nil {
 		panic(err)
 	}
-	fmt.Println(d)
+	for _, digit := range d {
+		fmt.Print(string(digit + 48))
+	}
+	fmt.Println()
 }
